#region 1. Using Statemetns
using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;

// Our own library
using XnaAssignments;
#endregion

namespace MyGame_Program
{
    /// <summary>
    ///  This is the main class. Notice this class must subclass from the XnaAssignmentBase
    /// </summary>
    public class MyGame : XnaAssignmentBase
    {
        #region Dimension of the room size
        // Private application state
        // Location and size of the world
        private const float WORLD_MIN_X = 0.0f;        // lower left corner is (0, 0)
        private const float WORLD_MIN_Y = 0.0f;
        private const float WORLD_WIDTH = 720f;        // width of the world 
        #endregion

        #region Constructor
        /// <summary>
        /// This is the constructor. Notice we must call the base class's constructor
        /// by passing in the coordinate of the lower-left corner, and the width of the world.
        /// </summary>
        public MyGame()
            : base(new Vector2(WORLD_MIN_X, WORLD_MIN_Y), WORLD_WIDTH)
        {
            //  Notice:  memory allocation and initialization should be performed
            //           in InitializedWorld(). The constructor should be empty.
        }
        #endregion


        Vector2 m_PositionBug;      // Position of the egg
        Vector2 m_VelocityBug;      // Velocity of the egg

        Vector2 m_PositionEgg;      // Position of the egg

        Vector2 m_PositionUmbrella; // Position of the umbrella

        #region Initialization of the world
        /// <summary>
        /// Initialize the application state
        /// </summary>
        protected override void InitializeWorld()
        {
            // allocate memory for the application
            m_PositionEgg = new Vector2();

            // initialize the Bug
            m_PositionBug.X = 240.0f;
            m_PositionBug.Y = 180.0f;

            m_VelocityBug.X = 15f;
            m_VelocityBug.Y = -5f;

            // initialize the Egg 
            m_PositionEgg.X = 240.0f;
            m_PositionEgg.Y = 180.0f;


            // initialize the Umbrella
            m_PositionUmbrella.X = 400.0f;
            m_PositionUmbrella.Y = 250.0f;

            XnaAssignmentBase.BackgroundColor = new Color(140, 140, 140);  // Gray-ish background
        }
        #endregion

        #region Update the game
        /// <summary>
        /// Update the application state. 
        /// </summary>
        protected override void UpdateWorld()
        {
            // Quits with the back button
            if (XnaAssignmentBase.GamePad.ButtonBackClicked())
                this.Exit();

            m_PositionBug.X = m_PositionBug.X + m_VelocityBug.X;
            m_PositionBug.Y = m_PositionBug.Y + m_VelocityBug.Y;

                        
            m_PositionEgg.X = m_PositionEgg.X + XnaAssignmentBase.GamePad.ThumbSticks.Left.X * 10;
            m_PositionEgg.Y = m_PositionEgg.Y + XnaAssignmentBase.GamePad.ThumbSticks.Left.Y * 10;

            // Notice one should never draw anything in the UpdateWorld() function!
        }
        #endregion

        #region Draw everything to the application window
        /// <summary>
        /// Draw the application state
        /// </summary>
        protected override void DrawWorld()
        {
            // Draw the Bee
            DrawRectangle(m_PositionEgg, 40 /* width */, 50 /* height */, 0.0f /*rotate */, Color.White, Color.White, @"egg");
            DrawRectangle(m_PositionBug, 40 /* width */, 50 /* height */, 0.0f /*rotate */, Color.White, Color.White, @"Insect0");
            DrawRectangle(m_PositionUmbrella, 40 /* width */, 50 /* height */, 0.0f /*rotate */, Color.White, Color.White, @"Umbrella");
            
            EchoToTopStatus(@" Lecture 7 Quiz Redo; Lecture 8 quiz");

            EchoToBottomStatus(@" <Clear>");


            EchoToBottomStatus(@"OVERLAPPING!");
        }
        #endregion
    }
}
